summaryrefslogtreecommitdiff
path: root/lib/getoptlong.rb
diff options
context:
space:
mode:
authormatz <matz@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2003-06-02 04:49:46 +0000
committermatz <matz@b2dd03c8-39d4-4d8f-98ff-823fe69b080e>2003-06-02 04:49:46 +0000
commit6125313d69c158b423d1f4aff2e206cfd43a036a (patch)
treea1a78a9425305557dcff6569806876989c9098c3 /lib/getoptlong.rb
parentf5a7f85917abed4d64ad908a4837e0db0499c951 (diff)
* array.c (push_values_at): Array#values_at should work with
ranges too. * range.c (rb_range_beg_len): length calculation was wrong. * eval.c (rb_call): should set T_ICLASS in the frame->last_class. [ruby-core:01110] git-svn-id: svn+ssh://ci.ruby-lang.org/ruby/trunk@3899 b2dd03c8-39d4-4d8f-98ff-823fe69b080e
Diffstat (limited to 'lib/getoptlong.rb')
-rw-r--r--lib/getoptlong.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/getoptlong.rb b/lib/getoptlong.rb
index 9c8ed09db9..7bb9baef2d 100644
--- a/lib/getoptlong.rb
+++ b/lib/getoptlong.rb
@@ -67,7 +67,7 @@ class GetoptLong
@argument_flags = Hash.new
#
# Whether error messages are output to stderr.
#
@quiet = FALSE
@@ -253,7 +253,7 @@ class GetoptLong
# Set an error (protected).
#
def set_error(type, message)
- $stderr.print("#{$0}: #{message}\n") if !@quiet
+ $deferr.print("#{$0}: #{message}\n") if !@quiet
@error = type
@error_message = message
@@ -67,7 +67,7 @@ class GetoptLong
#
- # Whether error messages are output to stderr.
+ # Whether error messages are output to $deferr.
#